@@ -12,9 +12,7 @@ class AGQueryPostgres:
     query: dict = None
     rows: list = []
 
-    def __init__(self, conn):
-        self.conn = conn
-
+    def __init__(self):
         self.SQL = ""
         self.inner_sql = ""
         self.query = {}
@@ -135,31 +133,4 @@ class AGQueryPostgresQueryLibrary:
         pass
 
 
-json = {
-    "schema_name": "lc",
-    "table_name": "products_product",
-    "select": ["code", "name", "pg.name"],
-    "down_relations": [
-        {
-            "schema_name": "lc",
-            "table_name": "customers_customerproduct",
-            "select": [
-                "cust.code", "cust.name"
-            ],
-            "relation": "product",
-            "where_string": "name > 'p'"
-        }
-    ],
-    "left_join": [
-        {
-            "schema_name": "lc",
-            "table_name": "products_productgroup",
-            "alias": "pg",
-            "relation": "product_group"
-        }
-    ]
-}
 
-q = AGQueryPostgres()
-result = q.build_sql(json)
-print(result)
