@@ -1,4 +1,6 @@
 from AGCoder import Coder
+from uuid import UUID
+import datetime
 
 
 class AGQueryWhere:
@@ -59,6 +61,10 @@ class AGQueryWhere:
                                     value = self._get_extract(value[0:-9], "quarter")
                             else:
                                 value = "'" + str(value) + "'"
+                    elif type(value) is UUID:
+                        value = "'" + str(value) + "'"
+                    elif type(value) is datetime.datetime:
+                        value = "'" + value.strftime('%Y-%m-%d %H:%M:%S') + "'"
                     else:
                         value = str(value)
 
